@@ -1,6 +1,6 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.055';
+$Statocles::App::Perldoc::VERSION = '0.056';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
@@ -103,8 +103,9 @@ sub pages {
 
             # Rewrite links for modules that we will be serving locally
             if ( grep { $href =~ /^$pod_base$_/ } @{ $self->modules } ) {
-                my ( $module ) = $href =~ /^$pod_base(.+)$/;
-                $node->attr( href => $self->url( $self->_module_href( $module ) ) );
+                my ( $module, $section ) = $href =~ /^$pod_base([^#]+)(?:\#(.*))?$/;
+                my $url = $self->url( $self->_module_href( $module ) );
+                $node->attr( href => $section ? join( "#", $url, $section ) : $url );
             }
             # Add rel="external" for remaining external links
             elsif ( $href =~ m{(?:[^:]+:)?//} ) {
@@ -272,7 +273,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 DESCRIPTION
 
