@@ -1,6 +1,6 @@
 package Statocles::App::Static;
-# ABSTRACT: Manage static files like CSS, JS, images, and other untemplated content
-$Statocles::App::Static::VERSION = '0.055';
+# ABSTRACT: (DEPRECATED) Manage static files like CSS, JS, images, and other untemplated content
+$Statocles::App::Static::VERSION = '0.056';
 use Statocles::Base 'Class';
 use Statocles::Page::File;
 with 'Statocles::App';
@@ -47,14 +47,18 @@ __END__
 
 =head1 NAME
 
-Statocles::App::Static - Manage static files like CSS, JS, images, and other untemplated content
+Statocles::App::Static - (DEPRECATED) Manage static files like CSS, JS, images, and other untemplated content
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 DESCRIPTION
 
+B<NOTE:> This application's functionality has been added to
+L<Statocles::App::Basic>. You can use the Basic app to replace this app. This
+class will be removed with v2.0. See L<Statocles::Help::Upgrading>.
+
 This L<Statocles::App|Statocles::App> manages static content with no processing,
 perfect for images, stylesheets, scripts, or already-built HTML.
 
