@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.055';
+$Statocles::Command::VERSION = '0.056';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -53,7 +53,33 @@ sub main {
         return 1;
     }
 
-    my $wire = Beam::Wire->new( file => $opt{config} );
+    my $wire = eval { Beam::Wire->new( file => $opt{config} ) };
+
+    if ( $@ ) {
+        if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::Config' ) ) {
+            my $remedy;
+            if ( $@ =~ /found character that cannot start any token/ ) {
+                $remedy = "Check that you are not using tabs for indentation. ";
+            }
+            elsif ( $@ =~ /did not find expected key/ ) {
+                $remedy = "Check your indentation. ";
+            }
+
+            my $more_info = ( !$opt{verbose} ? qq{run with the "--verbose" option or } : "" )
+                          . "check Statocles::Help::Error";
+
+            warn sprintf qq{ERROR: Could not load config file "%s". %sFor more information, %s.%s},
+                $opt{config},
+                $remedy,
+                $more_info,
+                ( $opt{verbose} ? "\n\nRaw error: $@" : "" )
+                ;
+
+            return 1;
+        }
+        die $@;
+    }
+
     my $site = eval { $wire->get( $opt{site} ) };
 
     if ( $@ ) {
@@ -565,7 +591,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 SYNOPSIS
 
