@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.055';
+$Statocles::Site::VERSION = '0.056';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -30,6 +30,7 @@ has theme => (
     isa => Theme,
     coerce => Theme->coercion,
     default => sub {
+        require Statocles::Theme;
         Statocles::Theme->new( store => '::default' );
     },
 );
@@ -327,14 +328,9 @@ sub build {
     $store->write_file( 'robots.txt', $robots->render );
 
     # Add the theme
-    my $theme_iter = $self->theme->store->find_files();
-    while ( my $theme_file = $theme_iter->() ) {
-        my $fh = $self->theme->store->open_file( $theme_file );
-        push @pages, Statocles::Page::File->new(
-            path => join( '/', '', 'theme', $theme_file ),
-            fh => $fh,
-        );
-        $store->write_file( Path::Tiny->new( 'theme', $theme_file ), $fh );
+    for my $page ( $self->theme->pages ) {
+        push @pages, $page;
+        $store->write_file( $page->path, $page );
     }
 
     $self->emit( build => class => 'Statocles::Event::Pages', pages => \@pages );
@@ -380,7 +376,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 SYNOPSIS
 
