@@ -1,18 +1,15 @@
 package Statocles::Theme;
 # ABSTRACT: Templates, headers, footers, and navigation
-$Statocles::Theme::VERSION = '0.055';
+$Statocles::Theme::VERSION = '0.056';
 use Statocles::Base 'Class';
 use File::Share qw( dist_dir );
 use Scalar::Util qw( blessed );
 use Statocles::Template;
+with 'Statocles::App::Role::Store';
 
 
-has store => (
-    is => 'ro',
-    isa => Store,
-    coerce => Store->coercion,
-    required => 1,
-);
+has '+url_root' => ( default => sub { '/theme' } );
+
 
 
 has include_stores => (
@@ -116,6 +113,13 @@ sub clear {
     return;
 }
 
+
+around pages => sub {
+    my ( $orig, $self, %args ) = @_;
+    my @pages = $self->$orig( %args );
+    return grep { $_->path !~ /[.]ep$/ } @pages;
+};
+
 1;
 
 __END__
@@ -128,7 +132,7 @@ Statocles::Theme - Templates, headers, footers, and navigation
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 SYNOPSIS
 
@@ -157,6 +161,10 @@ their name and their parent directory.
 
 =head1 ATTRIBUTES
 
+=head2 url_root
+
+The root URL for this application. Defaults to C</theme>.
+
 =head2 store
 
 The source L<store|Statocles::Store> for this theme.
@@ -220,6 +228,14 @@ L<include_stores|/include_stores> before looking in the L<main store|/store>.
 Clear out the cached templates and includes. Used by the daemon when it
 detects a change to the theme files.
 
+=head2 pages
+
+Get the extra, non-template files to deploy with the rest of the site, like CSS,
+JavaScript, and images.
+
+Templates, files that end in C<.ep>, will not be deployed with the rest of the
+site.
+
 =head1 SEE ALSO
 
 =over 4
